@@ -17,8 +17,7 @@ License : BSD (See COPYING)
 
 """
 
-__docformat__ = 'restructuredtext'
-
+from __future__ import print_function
 
 import inspect
 import re
@@ -48,6 +47,9 @@ from yolk.utils import run_command, command_successful
 from yolk.__init__ import __version__ as VERSION
 
 
+__docformat__ = 'restructuredtext'
+
+
 class StdOut:
 
     """Filter stdout or stderr from specific modules So far this is just used
@@ -64,8 +66,12 @@ class StdOut:
         return self.__dict__[attribute]
 
     def flush(self):
-        """Bug workaround for Python 3.2+: Exception AttributeError: 'flush' in
-        <yolk.cli.StdOut object..."""
+        """Bug workaround for Python 3.2+: Exception AttributeError: 'flush'
+        in.
+
+        <yolk.cli.StdOut object...
+
+        """
 
     def write(self, inline):
         """Write a line to stdout if it isn't in a blacklist.
@@ -188,7 +194,7 @@ class Yolk(object):
             (self.project_name, self.version, self.all_versions) = \
                 self.parse_pkg_ver(want_installed)
             if want_installed and not self.project_name:
-                logger.error('%s is not installed.' % pkg_spec[0])
+                logger.error('%s is not installed.' % pkg_spec)
                 return 1
 
         # I could prefix all these with 'cmd_' and the methods also
@@ -274,8 +280,6 @@ class Yolk(object):
         @returns: None or 2 if error
 
         """
-        show_metadata = self.options.metadata
-
         # Search for any plugins with active CLI options with add_column()
         # method
         plugins = self.get_plugin('add_column')
@@ -307,7 +311,6 @@ class Yolk(object):
                 for my_plugin in plugins:
                     # See if package is 'owned' by a package manager such as
                     # portage, apt, rpm etc.
-                    # add_column_text += my_plugin.add_column(filename) + " "
                     add_column_text += my_plugin.add_column(dist) + ' '
                 self.print_metadata(metadata, develop, active, add_column_text)
             else:
@@ -351,8 +354,7 @@ class Yolk(object):
         """
         show_metadata = self.options.metadata
         if self.options.fields:
-            fields = self.options.fields.split(',')
-            fields = map(str.strip, fields)
+            fields = [s.strip() for s in self.options.fields.split(',')]
         else:
             fields = []
         version = metadata['Version']
@@ -385,7 +387,7 @@ class Yolk(object):
                   ' - ' + status)
         if fields:
             # Only show specific fields, using case-insensitive search
-            fields = map(str.lower, fields)
+            fields = [s.lower() for s in fields]
             for field in metadata.keys():
                 if field.lower() in fields:
                     print('    %s: %s' % (field, metadata[field]))
@@ -399,7 +401,7 @@ class Yolk(object):
     def show_deps(self):
         """Show dependencies for package(s)
 
-        @returns: 0 - sucess  1 - No dependency info supplied
+        @returns: 0 - success  1 - No dependency info supplied
 
         """
 
@@ -409,14 +411,16 @@ class Yolk(object):
             if not self.version:
                 print(pkg.project_name, pkg.version)
 
-            i = len(pkg._dep_map.values()[0])
+            i = len(list(pkg._dep_map.values())[0])
             if i:
                 while i:
                     if not self.version or self.version and \
                             pkg.version == self.version:
-                        if self.version and i == len(pkg._dep_map.values()[0]):
+                        if self.version and i == len(list(
+                                pkg._dep_map.values())[0]):
                             print(pkg.project_name, pkg.version)
-                        print('  ' + str(pkg._dep_map.values()[0][i - 1]))
+                        print('  ' + str(list(
+                            pkg._dep_map.values())[0][i - 1]))
                     i -= 1
             else:
                 self.logger.info(
@@ -427,7 +431,7 @@ class Yolk(object):
     def show_pypi_changelog(self):
         """Show detailed PyPI ChangeLog for the last `hours`
 
-        @returns: 0 = sucess or 1 if failed to retrieve from XML-RPC server
+        @returns: 0 = success or 1 if failed to retrieve from XML-RPC server
 
         """
         hours = self.options.show_pypi_changelog
@@ -545,7 +549,6 @@ class Yolk(object):
         directory = '.'
 
         if self.options.file_type == 'svn':
-            version = 'dev'
             svn_uri = get_download_uri(self.project_name,
                                        'dev', True)
             if svn_uri:
@@ -691,12 +694,6 @@ class Yolk(object):
         @returns: 0 if version(s) found or 1 if none found
 
         """
-
-        if self.version:
-            spec = '%s==%s' % (self.project_name, self.version)
-        else:
-            spec = self.project_name
-
         if self.all_versions and self.version in self.all_versions:
             print_pkg_versions(self.project_name, [self.version])
         elif not self.version and self.all_versions:
@@ -1030,7 +1027,6 @@ def setup_opt_parser():
     opt_parser.add_option_group(group_local)
     opt_parser.add_option_group(group_pypi)
     # add opts from plugins
-    all_plugins = []
     for plugcls in load_plugins(others=True):
         plug = plugcls()
         try:
@@ -1075,6 +1071,3 @@ def main():
     """Let's do it."""
     my_yolk = Yolk()
     my_yolk.run()
-
-if __name__ == '__main__':
-    sys.exit(main())
